#
# spec file for package breeze4-style
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           breeze4-style
Version:        5.15.3
Release:        1.1
Summary:        Plasma Desktop artwork, styles and assets
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/breeze-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/plasma/%{version}/breeze-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
# PATCH-FIX-OPENSUSE add-support-for-Q3ListView-to-the-KDE4-style.patch boo#973728 wbauer@tmo.at -- fixes collapse/expand icon in Q3ListView that still may be used by some KDE4 applications (knode e.g.)
Patch0:         add-support-for-Q3ListView-to-the-KDE4-style.patch
BuildRequires:  automoc4
BuildRequires:  cmake >= 2.8.12
BuildRequires:  kde4-filesystem
BuildRequires:  libkde4-devel
BuildRequires:  libqt4-devel
BuildRequires:  libxcb-devel
# This sets the breeze4 style as default in a Plasma environment
Recommends:     kdebase4-workspace-libs
Supplements:    packageand(breeze5-style:libqt4)

%description
Artwork, styles and assets for the Breeze visual style for the Plasma Desktop.
This package contains kde4 backport of new default Plasma 5 style.

%package -n libbreezecommon4-5
Summary:        Library containing support code for the Breeze Qt4 style
Group:          System/Libraries

%description -n libbreezecommon4-5
Library containing support code for the Breeze Qt4 style.

%prep
%setup -q -n breeze-%{version}
%autopatch -p1

%build
  %cmake_kde4 -d build -- -DBUILD_po=OFF -DUSE_KDE4=ON
  %make_jobs

%install
  %kde4_makeinstall -C build

%post   -p /sbin/ldconfig -n libbreezecommon4-5
%postun -p /sbin/ldconfig -n libbreezecommon4-5

%files
%license COPYING*
%{_kde4_modulesdir}/
%{_kde4_appsdir}/

%files -n libbreezecommon4-5
%license COPYING*
%{_libdir}/libbreezecommon4.so.*

%changelog
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- Changes since 5.14.90:
  * Use correct window for getting ComboBox current icon pixmap
  * Update Breeze Dark Look and Feel theme previews
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * Export path of installed color-schemes in BreezeConfig cmake
  * Translate color scheme names
  * Fix typo
  * enable animations for standalone created buttons
  * Fix build of libbreezecommon with USE_KDE4
  * [libbreezecommon] Use box blur instead of FFT blur
  * Improve accuracy of some window decoration options' labels BUG: 399602 FIXED-IN: 5.15.0 (kde#399602)
  * Fix logic typo
  * Add KDE4 guard round mouse synthesised test
  * Don't drag windows in empty areas from touch/pen events
  * Link *-resize to the right icons
  * [cursors] Also link for Breeze Snow
  * [Cursors] link *-resize to *_corner cursor (kde#399194)
- Does not use FFTW anymore
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- No code changes since 5.14.4
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- Changes since 5.14.3:
  * Fix uncentered crosshairs
  * Improve contrast for crosshair cursors (kde#400110)
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- Changes since 5.14.2:
  * Link *-resize to the right icons
  * [cursors] Also link for Breeze Snow
  * [Cursors] link *-resize to *_corner cursor (kde#399194)
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- Changes since 5.13.90:
  * Allow to disable installation of wallpapers with breeze
  * Fix finding QtQuick (kde#398663)
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * Disable the title bar separator by default
  * [kstyle] Fix deprecation warnings
  * Properly use kpackage_install_package
  * Set complete vectors instead of creting them at runtime
  * Invert shade button by same logic as keep-above button
  * [kstyle] Create shadow tiles on demand
  * Rename libbreezecommon to libbreezecommon5 and don't install .so links
  * Only include QtQuick support in Breeze KStyle if QtQuick is available
  * Optimised 5.14 wallpaper filesizes and corrected banding issues.
  * Plasma 5.14 "Cluster" Wallpaper
  * [kdecoration] Delete unused includes
  * [libbreezecommon] Fix build when qreal is float
  * [kdecoration] Make shadows lighter
  * [kstyle] Refine shadows
  * [kdecoration] Refine shadows
  * [libbreezecommon] Add box shadow helper
  * Fixed detection of horizontal progressbar by re-introducing check on QStyleOptionProgressBar::orientation. Using option->state only even for Qt5 breaks ktorrent.
  * [kstyle] Don't suppress deprecation warnings
  * [kstyle] Drop QStyleOptionViewItemV4 in Qt 5 style plugin
  * [kstyle] Drop QStyleOptionTabWidgetFrameV2 in Qt 5 style plugin
  * [kstyle] Drop QStyleOptionTabV3 in Qt 5 style plugin
  * [kstyle] Drop QStyleOptionProgressBarV2 in Qt 5 style plugin
  * [kstyle] Drop QStyleOptionFrameV3 in Qt 5 style plugin
  * [kstyle] Drop QStyleOptionFrameV2 in Qt 5 style plugin
  * [kstyle] Drop QStyleOptionDockWidgetV2 in Qt 5 style plugin
  * Turn off the extended resize handle/black triangle when there are no borders
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * None
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * Check for option->styleObject before accessing it (kde#395028)
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * Draw mouse-over rect over the full toolbutton even if it has a menu
  * Plasma 5.13 "Kokkini" Wallpaper
  * Fix build with Qt 4
  * [kstyle] create shadow tiles more explicitly
  * [kstyle] use Q_FALLTHROUGH in breezesplitterproxy
  * [kdecoration] delete unused m_buttons field
  * [colors] add corresponding CMakeLists.txt
  * modernize: delete redundant return statements
  * modernize: delete redundant void args
  * modernize: use nullptr
  * delete COPYING-ICONS
  * [cursors] Add arrow cursor symlinks
  * - Moved shadowSize from anonymous namespace to static member function - calculate proper shadow size for Mdi windows - fix mdi windows shadow renderning.
  * Remove long-time deprecated Encoding=UTF-8 from desktop format file
  * fix double spacing bug
  * Fixed kde4 compilation. Fixed warning about blurhelper initialization.
  * Added optional transparency/blur to menu frames
  * Revert "Added option to set transparency and blur behind menu frames such as right click context menu, toolbar menu, etc."
  * align checkable widgets in menu items
  * Added option to set transparency and blur behind menu frames such as right click context menu, toolbar menu, etc. Transparency and blur is disabled by default. Submitted on behalf of Alex Nemeth
  * Revert "reserve space for checkable widgets in menu items"
  * reserve space for checkable widgets in menu items
  * Add the marking gcc likes to silence -Wimplicit-fallthrough= warning
  * fixed KDE4 compîlation (missing header)
  * ensure the rounded rectangle of scrollbard stays round
  * Fixed qt4 compilation.
  * even slimmer scrollbars
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * None
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * - Moved shadowSize from anonymous namespace to static member function - calculate proper shadow size for Mdi windows - fix mdi windows shadow renderning.
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * Render application icon at paintdevice DPR (kde#390639)
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Fix LnF theme data for window decoration
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * None
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Use combobox to choose shadow size and use more appropriate values for menu & tooltip shadow sizes
  * Remove obsolete reviewboardrc file
  * Adjusted range and default value for shadowsize and shadowcolor, to match the decoration settings. CCMAIL: pointedstick@zoho.com
  * Horizontally center shadows and make them bigger
  * Make it obvious what "Display window borders for maximized windows" is for
  * Fix indentation of icon for left aligned toolbuttons
  * Fix indentation of icon for left aligned toolbuttons
  * fixed comments
  * fixed icon state
  * When an icon is set to a QMenuBar Item, render the icon only, and ignore the text, when set, as this is what qmenubar expects. BUG: 387539 (kde#387539)
  * fixed comments
  * fixed icon state
  * When an icon is set to a QMenuBar Item, render the icon only, and ignore the text, when set, as this is what qmenubar expects. BUG: 387539 (kde#387539)
  * [Breeze window decoration] Use intersects instead of contains
  * [Breeze window decoration] Don't repaint title bar if not damaged
  * Removed heuristics for not drawing separator between titlebar and window since there is now a user configurable settings to achieve this
  * Set bottom border to zero for shaded windows
  * Implement SH_Widget_Animation_Duration style hint
  * Cleanup merge conflict
  * Very slightly increase text contrast for the default Breeze color scheme (kde#381288)
  * Added setting to toggle drawing of title bar separator
  * Add space in front of spinbox suffix "ms"
  * better contrast for Complementary areas
  * add license to .desktop file
  * use proper color for toolbutton text in some edge cases (thanks Kay for reporting! )
  * fixed icon mode in some toolbutton corner cases (explicitly: sunken but not on and not mouse over)
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * Fix indentation of icon for left aligned toolbuttons
  * fixed comments
  * fixed icon state
  * When an icon is set to a QMenuBar Item, render the icon only, and ignore the text, when set, as this is what qmenubar expects. BUG: 387539 (kde#387539)
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * [kstyle] Use KWindowSystem to determine on which platform we are
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Too many changes to list here
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Thu Aug 17 2017 fabian@ritter-vogt.de
- Recommend kdebase4-workspace-libs here instead of in patterns-kde
  to only install it with Qt4
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * - hide shadow when mask is empty - properly handle creating shadow when mdi window is already visible at registration - added some "auto" declarations CCBUG: 379790
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * use fontMetrics.height() rather than boundingRect(...).height() the height of the title bar should not depend on the caption content.
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * None
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * set a mask to shadow widget to make sure that it does not overlap with the mdi window. BUG:379790 (kde#379790)
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * fixed warning about unused variable
  * bump version for 5.9.5
  * Fix progress bar color
  * [cursors] Add 36px (1.5 scaling) size for Breeze and Breeze Snow Cursors (kde#348603)
  * Added new resolutions: 1366x768 and 1920x1200 Differential Revision: https://phabricator.kde.org/D4400
  * Fix header content size when sorting is disabled
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * bump version for 5.9.5
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * Use QPalette::Shadow instead of QPalette::Text to darken inactive tabs BUG:373088
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * [KStyle] Don't draw focus indicator on ComboBox entries
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * [lookandfeel] Breeze window decoration
* Sat Jan 14 2017 herbert@graeber-clan.de
- Supplement packagand(breeze5-stlye:libqt4) as a replecement for
  Requires/Recommends in plasma5-session and breeze5-style
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * Draw scrollbar as focused when scrollbar itself have focus.
  * Plasma 5.9 wallpaper "Canopee".
  * Implement drag from free space also for QtQuickControls.
  * Default to no arrows.
  * Make scrollbar size configurable.
  * Removed unnecessary ifdef.
  * Fix flickering arrows.
  * Fixed warning about unused variable.
  * Fixed warning about unused variables.
  * Fixed compilation for KDE4.
  * The combobox needs to be 2 pixels wider for contents to fit.
  * Show full scrollbar only on mouse over.
  * Fix broken kcfgc files.
  * [kstyle] Implement window moving on Wayland.
  * Fix crash on exit.
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Sun Oct 23 2016 wbauer@tmo.at
- Update add-support-for-Q3ListView-to-the-KDE4-style.patch to fix
  some graphical glitches (boo#1005902)
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Sun Oct  2 2016 wbauer@tmo.at
- Add add-support-for-Q3ListView-to-the-KDE4-style.patch to fix
  the display of the collapse/expand icon in Q3ListView that still
  may be used by some KDE4 applications, knode e.g. (boo#973728)
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
  . Drop Use-NETRootInfo-to-initiate-wm-move-operation.patch, upstreamed
* Sat Oct 10 2015 hrvoje.senjan@gmail.com
- Added Use-NETRootInfo-to-initiate-wm-move-operation.patch
  (kde#353749)
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Drop patches merged upstream:
  0001-Cleanup-code-to-align-with-master.patch,
  0002-set-button-s-visibility-depending-on-the-availabilit.patch,
  0003-Properly-update-size-grip-visibility-on-maximizedCha.patch
  and 0004-Fixed-foreground-color-for-pressed-buttons.patch
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
- Drop patches merged upstream:
  0003-return-parent-style-method-when-option-passed-to-tab.patch,
  0002-Check-scrollbar-policy-before-forwarding-events.patch,
  0004-check-widget-validity-before-calling-deleteLater.patch and
  0001-Added-an-explicit-flag-as-output-from-captionRect-to.patch
- Added patches from upstream:
  0001-Cleanup-code-to-align-with-master.patch (kde#345424),
  0002-set-button-s-visibility-depending-on-the-availabilit.patch
  (kde#343641),
  0003-Properly-update-size-grip-visibility-on-maximizedCha.patch
  and 0004-Fixed-foreground-color-for-pressed-buttons.patch
* Tue Mar 10 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Added-an-explicit-flag-as-output-from-captionRect-to.patch,
  0002-Check-scrollbar-policy-before-forwarding-events.patch,
  0003-return-parent-style-method-when-option-passed-to-tab.patch
  and 0004-check-widget-validity-before-calling-deleteLater.patch
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * Fix ui files
  * Fixed color role for accelerator
  * Added inputWidgetEngine, for abstract item views, line editors,
    spinboxes and comboboxes it is needed to avoid animation
    conflicts between lists and buttons (when, e.g. there is a
    checkbox inside a list)
  * Removed Q3ListView support
  * Manually calculate viewport update rect on header hover change
    kde#340343
  * Fixed KDE4 compilation. kde#341006
  * Remove mnemonic underlines when alt-tabbing
  * Removed unused members
  * Fixed uninitialized member _value
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Do not clip away vertical margins for headers, kde#340150
  * Properly handle RTL for corner rects and tabbar, kde#340155
  * Center icon in tabs when there is no text and no buttons, kde#340257
  * Do not takeout margins from toolbutton before rendering text,
    unless they have inline indicator, kde#340341
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
- Drop dont-build-translations.patch, fixed upstream
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor tweaks to breeze style since previous update
- Added dont-build-translations.patch: we don't want translations
  built twice
* Wed Sep 24 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140924
  * Many improvements for the Breeze style
- Drop pkgconfig(x11) BuildRequires
* Tue Aug 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140826
  * new C++ Qt5 style (with option to build kde4 style also)
  * updated icons
- Split the main package to icons, cursors, wallpapers, decoration
  and style packages
- Added frameworkintegration-devel, kcompletion-devel, ki18n-devel,
  kwindowsystem-devel, pkgconfig(Qt5DBus), pkgconfig(Qt5Widgets),
  pkgconfig(Qt5X11Extras), pkgconfig(x11), pkgconfig(x11-xcb) and
  pkgconfig(xcb)
- Drop qtcurve-(qt4,qt5) Recommends and Requires due to switch of
  default to new style
- Create breeze4-style package
- Comment out Source URL temporarily
* Mon Aug 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
- Update license
- Add Source URL
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Thu Jun  5 2014 hrvoje.senjan@gmail.com
- Activate breeze package
